package com.zhyc.module.biosafety.service;

import java.util.List;
import com.zhyc.module.biosafety.domain.SwUsage;

/**
 * 药品使用方法Service接口
 * 
 * @author ruoyi
 * @date 2025-07-11
 */
public interface ISwUsageService 
{
    /**
     * 查询药品使用方法
     * 
     * @param id 药品使用方法主键
     * @return 药品使用方法
     */
    public SwUsage selectSwUsageById(Long id);

    /**
     * 查询药品使用方法列表
     * 
     * @param swUsage 药品使用方法
     * @return 药品使用方法集合
     */
    public List<SwUsage> selectSwUsageList(SwUsage swUsage);

    /**
     * 新增药品使用方法
     * 
     * @param swUsage 药品使用方法
     * @return 结果
     */
    public int insertSwUsage(SwUsage swUsage);

    /**
     * 修改药品使用方法
     * 
     * @param swUsage 药品使用方法
     * @return 结果
     */
    public int updateSwUsage(SwUsage swUsage);

    /**
     * 批量删除药品使用方法
     * 
     * @param ids 需要删除的药品使用方法主键集合
     * @return 结果
     */
    public int deleteSwUsageByIds(Long[] ids);

    /**
     * 删除药品使用方法信息
     * 
     * @param id 药品使用方法主键
     * @return 结果
     */
    public int deleteSwUsageById(Long id);
}
