package com.zhyc.module.biosafety.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.zhyc.module.biosafety.domain.SwUsage;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zhyc.common.annotation.Log;
import com.zhyc.common.core.controller.BaseController;
import com.zhyc.common.core.domain.AjaxResult;
import com.zhyc.common.enums.BusinessType;
import com.zhyc.module.biosafety.service.ISwUsageService;
import com.zhyc.common.utils.poi.ExcelUtil;
import com.zhyc.common.core.page.TableDataInfo;

/**
 * 药品使用方法Controller
 * 
 * @author ruoyi
 * @date 2025-07-11
 */
@RestController
@RequestMapping("/biosafety/usage")
public class SwUsageController extends BaseController
{
    @Autowired
    private ISwUsageService swUsageService;

    /**
     * 查询药品使用方法列表
     */
    @PreAuthorize("@ss.hasPermi('biosafety:usage:list')")
    @GetMapping("/list")
    public TableDataInfo list(SwUsage swUsage)
    {
        startPage();
        List<SwUsage> list = swUsageService.selectSwUsageList(swUsage);
        return getDataTable(list);
    }

    /**
     * 导出药品使用方法列表
     */
    @PreAuthorize("@ss.hasPermi('biosafety:usage:export')")
    @Log(title = "药品使用方法", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SwUsage swUsage)
    {
        List<SwUsage> list = swUsageService.selectSwUsageList(swUsage);
        ExcelUtil<SwUsage> util = new ExcelUtil<SwUsage>(SwUsage.class);
        util.exportExcel(response, list, "药品使用方法数据");
    }

    /**
     * 获取药品使用方法详细信息
     */
    @PreAuthorize("@ss.hasPermi('biosafety:usage:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(swUsageService.selectSwUsageById(id));
    }

    /**
     * 新增药品使用方法
     */
    @PreAuthorize("@ss.hasPermi('biosafety:usage:add')")
    @Log(title = "药品使用方法", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SwUsage swUsage)
    {
        return toAjax(swUsageService.insertSwUsage(swUsage));
    }

    /**
     * 修改药品使用方法
     */
    @PreAuthorize("@ss.hasPermi('biosafety:usage:edit')")
    @Log(title = "药品使用方法", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SwUsage swUsage)
    {
        return toAjax(swUsageService.updateSwUsage(swUsage));
    }

    /**
     * 删除药品使用方法
     */
    @PreAuthorize("@ss.hasPermi('biosafety:usage:remove')")
    @Log(title = "药品使用方法", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(swUsageService.deleteSwUsageByIds(ids));
    }
}
